#!/bin/bash
cd rustdesk
SOURCE=$(pwd)
apt-get update
apt-get install -y dialog

# ask for domain and email address
DOMAIN=""
MAIL=""
INPUT="/tmp/input.txt"
dialog --title "Installation RustDesk" --inputbox "Domain name" 10 40 2>$INPUT
response=$?
DOMAIN=$(cat $INPUT)
if [ "$response" = "1" ]
then
  exit
fi
if [ "$response" = "255" ]
then
  exit
fi
if [ "$DOMAIN" = "" ]
then
  exit
fi

dialog --title "Installation RustDesk" --inputbox "Email address" 10 40 2>$INPUT
MAIL=$(cat $INPUT)
response=$?
if [ "$response" = "1" ]
then
  exit
fi
if [ "$response" = "255" ]
then
  exit
fi
if [ "$DOMAIN" = "" ]
then
  exit
fi

apt-get install -y docker.io > $SOURCE/install.out 2> $SOURCE/install.err
apt-get install -y nginx > $SOURCE/install.out 2> $SOURCE/install.err
apt-get install -y certbot python3-certbot-nginx > $SOURCE/install.out 2> $SOURCE/install.err
# start docker
systemctl start docker > $SOURCE/install.out 2> $SOURCE/install.err
systemctl enable docker > $SOURCE/install.out 2> $SOURCE/install.err

# install rustdesk container
curl -L "https://github.com/docker/compose/releases/download/1.29.2/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose > $SOURCE/install.out 2> $SOURCE/install.err
chmod +x /usr/local/bin/docker-compose > $SOURCE/install.out 2> $SOURCE/install.err
mkdir -p /opt/rustdesk > $SOURCE/install.out 2> $SOURCE/install.err
cp rustdesk.yml /opt/rustdesk > $SOURCE/install.out 2> $SOURCE/install.err
cd /opt/rustdesk > $SOURCE/install.out 2> $SOURCE/install.err
docker-compose -f rustdesk.yml up -d > $SOURCE/install.out 2> $SOURCE/install.err

# config nginx
cd $SOURCE
cp nginx.conf /etc/nginx/conf.d/$DOMAIN > $SOURCE/install.out 2> $SOURCE/install.err
sed -e "s/DOMAIN/$DOMAIN/g" -i /etc/nginx/conf.d/$DOMAIN > $SOURCE/install.out 2> $SOURCE/install.err
systemctl restart nginx > $SOURCE/install.out 2> $SOURCE/install.err
certbot --nginx -m $MAIL -d $DOMAIN --noninteractive --agree-tos > $SOURCE/install.out 2> $SOURCE/install.err
systemctl reload nginx > $SOURCE/install.out 2> $SOURCE/install.err

# allow ports
ufw allow ssh
ufw allow http
ufw allow https
ufw allow 21114:21119/tcp
ufw allow 21116/udp
ufw enable > $SOURCE/install.out 2> $SOURCE/install.err

if [ -s $SOURCE/install.err ]
then
    echo "**************************************************"
    echo "*  error installation (see $SOURCE/install.err): *"
    echo "**************************************************"
    cat $SOURCE/install.err
fi

# Key for client
echo "------------------------------------------------------------------------"
echo "Installation complete"
echo "Copy this output. Public key is needed to configure the RustDesk client:"
more /opt/rustdesk/hbbs/id_ed25519.pub
exit 0
